import json

import pytest

from infection_monkey.exploit.wmiexec import WmiExploiter
from infection_monkey.model.host import VictimHost
from infection_monkey.telemetry.exploit_telem import ExploitTelem


DOMAIN_NAME = "domain-name"
IP = "0.0.0.0"
HOST = VictimHost(IP, DOMAIN_NAME)
HOST_AS_DICT = {
    "ip_addr": IP,
    "domain_name": DOMAIN_NAME,
    "os": {},
    "services": {},
    "icmp": False,
    "monkey_exe": None,
    "default_tunnel": None,
    "default_server": None,
}
EXPLOITER = WmiExploiter(HOST)
EXPLOITER_NAME = "WmiExploiter"
EXPLOITER_INFO = {
    "display_name": WmiExploiter._EXPLOITED_SERVICE,
    "started": "",
    "finished": "",
    "vulnerable_urls": [],
    "vulnerable_ports": [],
    "executed_cmds": [],
}
EXPLOITER_ATTEMPTS = []
RESULT = False


@pytest.fixture
def exploit_telem_test_instance():
    return ExploitTelem(EXPLOITER, RESULT)


def test_exploit_telem_send(exploit_telem_test_instance, spy_send_telemetry):
    exploit_telem_test_instance.send()
    expected_data = {
        "result": RESULT,
        "machine": HOST_AS_DICT,
        "exploiter": EXPLOITER_NAME,
        "info": EXPLOITER_INFO,
        "attempts": EXPLOITER_ATTEMPTS,
    }
    expected_data = json.dumps(expected_data, cls=exploit_telem_test_instance.json_encoder)
    assert spy_send_telemetry.data == expected_data
    assert spy_send_telemetry.telem_category == "exploit"
